@@ -530,7 +530,15 @@ def stacked_grouped_bar_chart(df, **kwargs):
             px.colors.qualitative.Plotly[: len(df.columns.levels[1])],
         )
     )
-    showlegend = [i % len(df.columns.levels[0]) == 0 for i in range(len(df.columns))]
+
+    seen_commod = set()
+    showlegend = []
+    for src, prod in df.columns:
+        if prod not in seen_commod:
+            showlegend.append(True)
+            seen_commod.add(prod)
+        else:
+            showlegend.append(False)
 
     # xaxis_tickformat doesn't appear to work so have to format the dataframe index
     if isinstance(df.index, pd.DatetimeIndex):
@@ -538,11 +546,11 @@ def stacked_grouped_bar_chart(df, **kwargs):
         freq = pd.infer_freq(df.index)
         if freq is not None:
             if freq in ("M", "MS", "ME"):
-                df.index = df.index.map(lambda x: x.strftime("%m-%Y"), 1)
+                df.index = df.index.map(lambda x: x.strftime("%m-%Y"))
             if freq in ("Y", "YS", "YE"):
-                df.index = df.index.map(lambda x: x.year, 1)
+                df.index = df.index.map(lambda x: x.year )
             if freq in ("D", "B"):
-                df.index = df.index.map(lambda x: x.date(), 1)
+                df.index = df.index.map(lambda x: x.date())
 
     i = 0
     for col in df.columns:
